/* * * * * * * * * * * * * * * * * * * * * * 
 *  eSpeakPackage.h  -- Header to utilize the eSpeak package within C
 *
 *  eSpeak's author:  Jonathan Duddington
 *  eSpeak source:  http://espeak.sourceforge.net/
 *
 *  author of this adaptation package:  Henry M. Walker
 *  last revised for Linux:  October 3, 2013
 *  last revised for Macintosh:  February 21, 2015
 *
 * This program and all MyroC software is licensed under the Creative Commons
 * Attribution-Noncommercial-Share Alike 4.0 International License.
 * Details may be found at http://creativecommons.org/licenses/by-nc-sa/4.0/
 *
 * * * * * * * * * * * * * * * * * * * * * */

/* Note: each function name starts with eSpeak to make it 
   easier to understand whether it is a speech function. */

#ifndef _eSpeak
#define _eSpeak

/* set up the local environment to utilize the eSpeak package 
 */
void eSpeakConnect ();

/* clean up the local environment when the eSpeak package is no longer needed
 */
void eSpeakDisconnect ();

/* generate audio for the user
   @param text:  the string to be converted to audible speech
                    --- any string is valid
                 (for Linux compatibility, string should not begin with
                     eSpeakABBCCCDDDEEEEFFFF   
                 )
 */
void eSpeakTalk (const char * text);

/* set quality of voice to female or male 
   @param gender:  "female" sets woman's voice
                   "male"   sets man's voice
   if gender is neither "female" nor "male", voice unchanged
*/
void eSpeakSetGender (const char * gender);

#endif
